//<!--
var httpkeepUrl;
var appletDescription;
var httpObj;
var nextKey;
var nowKey;
var sessionId;
var keepConnect;
var cookieName;

function createXMLHttpRequest() {
  try { return new ActiveXObject("Msxml2.XMLHTTP");    } catch(e) {}
  try { return new ActiveXObject("Microsoft.XMLHTTP"); } catch(e) {}
  try { return new XMLHttpRequest();                   } catch(e) {}
  return null;
}

function sendHello(){

  // http communication
  if((httpObj=createXMLHttpRequest())!=null){
    httpObj.onreadystatechange = displayResponse;

    try{  
      httpObj.open("GET",httpkeepUrl+"-"+nowKey+"-"+hex_md5(nextKey+sessionId) ,true);
      httpObj.send(null);
      nowKey=nextKey;
      rand=Math.random();
      nextKey=hex_md5(String(rand));
    }catch(e){
	showError();
    }
  }
  else{
      showError();
  }
}

function displayResponse()
{
  try{
    if(httpObj.readyState==4){
      if(httpObj.status==200){
        today=new Date; 
        hh=today.getHours();  mm=today.getMinutes();
        if(hh<10)hh='0'+hh;   if(mm<10)mm='0'+mm;
        document.getElementById("dispmsg").innerHTML = hh+':'+mm;
        if(httpObj.responseText=="hello") sendHello();
      }else{
	  showError();
      }
    }
  }catch(e){
      showError();
  }
}

function showError(){
      document.getElementById("watchdog").innerHTML = "Error!, Close This page";
      document.getElementById("watchdog").style.backgroundColor = "pink";
      document.title = "Useless Page";
      keepConnect=false;
}

function clearCookie(){
  if(keepConnect){
    document.cookie = cookieName+"=;";
  }
}

function endHttpkeep(){

  //clear cookie
  clearCookie(); 

  if(httpObj!=null){
    httpObj.abort();
  }
}

function initHttpkeep(urlArg, sid, ckName)
{

  // save arguments
  httpkeepUrl=urlArg;
  nowKey=hex_md5(sid);
  cookieName=ckName;
  sessionId=sid;
  rand=Math.random();
  nextKey=hex_md5(String(rand));
  keepConnect=true;

  // set timeout and send hello 
  sendHello();
}
//-->
